Learn R Programming

maxLik (version 1.4-6)

nIter: Return number of iterations for iterative models

Description

Returns the number of iterations for iterative models. The default method assumes presence of a component iterations in x.

Usage

nIter(x, …)
# S3 method for default
nIter(x, …)

Arguments

x

a statistical model, or a result of maximisation, created by maxLik, maxNR or another optimizer.

…

further arguments for methods

Value

numeric, number of iterations. Note that ‘iteration’ may mean different things for different optimizers.

Details

This is a generic function. The default method returns the component x$iterations.

See Also

maxLik, maxNR

Examples

Run this code
# NOT RUN {
## Estimate the exponential distribution parameter:
t <- rexp(100, 2)
loglik <- function(theta) sum(log(theta) - theta*t)
## Estimate with numeric gradient and numeric Hessian
a <- maxNR(loglik, start=1)
nIter(a)
# }

Run the code above in your browser using DataLab