Learn R Programming

maxLik (version 0.5-12)

vcov.maxLik: Variance Covariance Matrix of maxLik objects

Description

Extract variance-covariance matrices of objects of class maxLik.

Usage

## S3 method for class 'maxLik':
vcov( object, eigentol=1e-12, ... )

Arguments

object
an object of class probit or maxLik.
eigentol
nonzero print limit on the range of the absolute values of the hessian. Specifically, define:

absEig <- eigen(hessian(object), symmetric=TRUE)[['values']]

Then compute and print t values, p values, etc. only if min(absEig) > (eigent

...
further arguments (currently ignored).

Value

  • the estimated variance covariance matrix of the coefficients.

See Also

vcov, maxLik.

Examples

Run this code
## ML estimation of exponential duration model:
t <- rexp(100, 2)
loglik <- function(theta) log(theta) - theta*t
gradlik <- function(theta) 1/theta - t
hesslik <- function(theta) -100/theta^2
## Estimate with numeric gradient and hessian
a <- maxLik(loglik, start=1, print.level=2)
vcov(a)
## Estimate with analytic gradient and hessian
a <- maxLik(loglik, gradlik, hesslik, start=1)
vcov(a)

Run the code above in your browser using DataLab